from modele.get_connector import get_connector

def select_produits():
    # 0 : on écrit la requête SQL
    query = (
        "SELECT "
        "    id_produit, "
        "    nom_produit, "
        "    prix_produit, "
        "    image_produit "
        "FROM produits "
        "ORDER BY id_produit"
    )
    # 1 : on se connecte à la BD
    cnx = get_connector()  # On suppose que cette fonction renvoie une connexion valide.
    if cnx is None:  # Vérifie si la connexion a échoué sans lever d'exception
        return []  # Retourne une liste vide: c'est un échec
    cursor = cnx.cursor()
    # 2 : on exécute la requête
    cursor.execute(query)
    # 3 on parcours les résultats pour fabriquer une liste de dictionnaires type table excel
    produits = []
    for (id_produit, nom_produit, prix_produit, image_produit) in cursor:
        produits.append({
            "id_produit": id_produit, 
            "nom_produit": nom_produit, 
            "prix_produit": prix_produit, 
            "image_produit": image_produit
        })
    # 4 : on ferme la connexion à la BD
    cursor.close()
    cnx.close()
    # 5 : on returne la liste
    return produits


def insert_produit(nom, prix, image):
    # 0 : on écrit la requête SQL
    query = (
        "INSERT INTO produits" 
            "(nom_produit, prix_produit, image_produit)"
        "VALUES (%s, %s, %s)"
    )
    # 1 : on se connecte à la BD
    cnx= get_connector()
    if cnx is None:  # Vérifie si la connexion a échoué sans lever d'exception
        return 0  # Retourne l'ID 0 qui n'existe pas: c'est un échec
    cursor = cnx.cursor()
    # 2 : on exécute la requête et on valide l'exécution : commit
    cursor.execute(query, (nom, prix, image))
    cnx.commit()
    # 3 : On récupère l'ID du dernier enregistrement inséré
    last_id = cursor.lastrowid  
    # 4 : on ferme la connexion à la BD
    cursor.close()
    cnx.close()
    # 5 : On retourne l'ID ajoutée
    return last_id  
